@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 Bart
+/* Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,14 +29,6 @@ Dialog_Partition_New::Dialog_Partition_New()
 	
 	//set used (in pixels)...
 	frame_resizer_base ->set_used( 0 ) ;
-	
-	//checkbutton..
-	checkbutton_round_to_cylinders .set_label( _("Round to cylinders") ) ;
-	checkbutton_round_to_cylinders .set_active( true ) ;
-	checkbutton_round_to_cylinders .signal_clicked() .connect( 
-		sigc::bind<bool>( sigc::mem_fun(*this, &Dialog_Partition_New::optionmenu_changed), false ) ) ;
-
-	this ->get_vbox() ->pack_start( checkbutton_round_to_cylinders, Gtk::PACK_SHRINK ) ;
 }
 
 void Dialog_Partition_New::Set_Data( const Partition & partition,
@@ -107,7 +99,19 @@ void Dialog_Partition_New::Set_Data( const Partition & partition,
 	optionmenu_filesystem .signal_changed() .connect( 
 		sigc::bind<bool>( sigc::mem_fun( *this, &Dialog_Partition_New::optionmenu_changed ), false ) );
 	table_create .attach( optionmenu_filesystem, 1, 2, 1, 2, Gtk::FILL );
-	
+
+	//Label
+	table_create .attach( * Utils::mk_label( Glib::ustring( _("Label:") ) ),
+			0, 1, 3, 4,	Gtk::FILL ) ;
+	//Create Text entry box
+	entry .set_max_length( 30 );
+	entry .set_width_chars( 20 );
+	entry .set_activates_default( true );
+	entry .set_text( partition.label );
+	entry .select_region( 0, entry .get_text_length() );
+	//Add entry box to table
+	table_create .attach( entry, 1, 2, 3, 4, Gtk::FILL ) ;
+
 	//set some widely used values...
 	START = partition.sector_start ;
 	total_length = partition.sector_end - partition.sector_start ;
@@ -144,9 +148,11 @@ Partition Dialog_Partition_New::Get_New_Partition()
 
 		default	:	part_type = GParted::TYPE_UNALLOCATED ;
 	}
-	
-	new_start = START + (spinbutton_before .get_value_as_int() * MEBIBYTE) ;
-	new_end  = new_start + (spinbutton_size .get_value_as_int() * MEBIBYTE) ;
+
+	//FIXME:  Partition size is limited to just less than 1024 TeraBytes due
+	//        to the maximum value of signed 4 byte integer.
+	new_start = START + (Sector(spinbutton_before .get_value_as_int()) * MEBIBYTE) ;
+	new_end  = new_start + (Sector(spinbutton_size .get_value_as_int()) * MEBIBYTE) ;
 	
 	/* due to loss of precision during calcs from Sector -> MiB and back, it is possible the new 
 	 * partition thinks it's bigger then it can be. Here we try to solve this.*/
@@ -161,7 +167,10 @@ Partition Dialog_Partition_New::Get_New_Partition()
 			new_count, part_type,
 			FILESYSTEMS[ optionmenu_filesystem .get_history() ] .filesystem,
 			new_start, new_end, 
-			selected_partition .inside_extended, false ) ; 
+			selected_partition .inside_extended, false ) ;
+
+	//Retrieve Label info
+	part_temp .label = Utils::trim( entry .get_text() );
 	
 	//grow new partition a bit if freespaces are < 1 MiB
 	if ( (part_temp.sector_start - selected_partition.sector_start) < MEBIBYTE ) 
@@ -180,6 +189,7 @@ Partition Dialog_Partition_New::Get_New_Partition()
 		part_temp .logicals .push_back( UNALLOCATED ) ;
 	}
 
+	//set indicator of whether to use strict sector values, or to round to cylinders
 	part_temp .strict = ! checkbutton_round_to_cylinders .get_active() ;
 
 	return part_temp;
