@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 Bart 'plors' Hakvoort
+/* Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include "../include/OperationDelete.h"
 #include "../include/OperationFormat.h"
 #include "../include/OperationResizeMove.h"
+#include "../include/OperationLabelPartition.h"
 
 #include "../include/ext2.h"
 #include "../include/ext3.h"
@@ -38,22 +39,13 @@
 #include "../include/ufs.h"
 
 #include <cerrno>
-#include <cstdio>
-#include <csignal>
-#include <sys/statvfs.h>	
+#include <sys/statvfs.h>
 
 std::vector<Glib::ustring> libparted_messages ; //see ped_exception_handler()
 
 namespace GParted
 {
 
-// Clean up the fdi when terminating
-void sig_fdi_cleanup( int signum )
-{
-	remove( "/usr/share/hal/fdi/policy/gparted-disable-automount.fdi" );
-	raise( signum );
-}
-
 GParted_Core::GParted_Core() 
 {
 	lp_device = NULL ;
@@ -63,44 +55,6 @@ GParted_Core::GParted_Core()
 
 	ped_exception_set_handler( ped_exception_handler ) ; 
 
-	//make sure that the fdi is cleaned up on all but the most forceful
-	//program exits
-	struct sigaction sa;
-	sa.sa_handler = sig_fdi_cleanup;
-	sigemptyset( &sa.sa_mask );
-	sa.sa_flags = SA_RESETHAND;
-	if( sigaction( SIGHUP, &sa, NULL ) == -1 ||
-	    sigaction( SIGINT, &sa, NULL ) == -1 ||
-	    sigaction( SIGQUIT, &sa, NULL ) == -1 ||
-	    sigaction( SIGILL, &sa, NULL ) == -1 ||
-	    sigaction( SIGABRT, &sa, NULL ) == -1 ||
-	    sigaction( SIGFPE, &sa, NULL ) == -1 ||
-	    sigaction( SIGSEGV, &sa, NULL ) == -1 ||
-	    sigaction( SIGPIPE, &sa, NULL ) == -1 ||
-	    sigaction( SIGALRM, &sa, NULL ) == -1 ||
-	    sigaction( SIGTERM, &sa, NULL ) == -1 ||
-	    sigaction( SIGUSR1, &sa, NULL ) == -1 ||
-	    sigaction( SIGUSR2, &sa, NULL ) == -1 ||
-	    sigaction( SIGBUS, &sa, NULL ) == -1 ||
-	    sigaction( SIGXCPU, &sa, NULL ) == -1 ||
-	    sigaction( SIGXFSZ, &sa, NULL ) == -1 )
-		perror( "Could not set signal handler" );
-	
-	//disable automount //FIXME: temporary hack, till i find a better solution...
-	std::ofstream fdi_file( "/usr/share/hal/fdi/policy/gparted-disable-automount.fdi" ) ;
-	if ( fdi_file )
-	{
-		fdi_file << "<deviceinfo version='0.2'>" ;
-		fdi_file << "<device>" ;
-		fdi_file << "<match key='storage.hotpluggable' bool='true'>" ;
-		fdi_file << "<merge key='storage.automount_enabled_hint' type='bool'>false</merge>" ;
-		fdi_file << "</match>" ;
-		fdi_file << "</device>" ;
-		fdi_file << "</deviceinfo>" ;
-
-		fdi_file .close() ;
-	}	
-
 	//get valid flags ...
 	for ( PedPartitionFlag flag = ped_partition_flag_next( static_cast<PedPartitionFlag>( NULL ) ) ;
 	      flag ;
@@ -111,7 +65,7 @@ GParted_Core::GParted_Core()
 	std::cout << "======================" << std::endl ;
 	std::cout << "libparted : " << ped_get_version() << std::endl ;
 	std::cout << "======================" << std::endl ;
-	
+
 	//initialize filesystemlist
 	find_supported_filesystems() ;
 }
@@ -155,7 +109,7 @@ void GParted_Core::find_supported_filesystems()
 	
 	ufs fs_ufs;
 	FILESYSTEMS .push_back( fs_ufs .get_filesystem_support() ) ;
-	
+
 	xfs fs_xfs;
 	FILESYSTEMS .push_back( fs_xfs .get_filesystem_support() ) ;
 	
@@ -181,9 +135,34 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 	if ( probe_devices )
 	{
 		device_paths .clear() ;
-		
+
 		//try to find all available devices
-		ped_device_probe_all();
+		std::ifstream proc_partitions( "/proc/partitions" ) ;
+    	if ( proc_partitions )
+    	{
+    		//parse device names from /proc/partitions
+    		std::string line ;
+    		std::string device ;
+    		while ( getline( proc_partitions, line ) )
+    		{
+    			//Device names without a trailing digit refer to the whole disk.
+    			//These whole disk devices are the ones we want.
+    			device = Utils::regexp_label(line, "^[\t ]+[0-9]+[\t ]+[0-9]+[\t ]+[0-9]+[\t ]+([^0-9]+)$") ;
+    			if ( device != "" )
+    			{
+    				//try to have libparted detect the device and add it to the list
+    				device = "/dev/" + device;
+    				ped_device_get( device .c_str() ) ;
+    			}
+    		}
+    		proc_partitions .close() ;
+    	}
+    	else
+    	{
+    		//file /proc/partitions doesn't exist so use libparted to probe devices
+    		ped_device_probe_all();
+    	}
+
 		lp_device = ped_device_get_next( NULL );
 		while ( lp_device ) 
 		{
@@ -198,10 +177,8 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 
 					ped_device_close( lp_device ) ;
 				}
-
 				free( buf ) ;
 			}
-			
 			lp_device = ped_device_get_next( lp_device ) ;
 		}
 		close_device_and_disk() ;
@@ -273,9 +250,23 @@ bool GParted_Core::snap_to_cylinder( const Device & device, Partition & partitio
 {
 	if ( ! partition .strict )
 	{
-		//FIXME: this doesn't work to well, when dealing with layouts which contain an extended partition
-		//because of the metadata length % cylindersize isn't always 0
-		Sector diff = partition .sector_start % device .cylsize ;
+		Sector diff = 0;
+		if ( partition.type == TYPE_LOGICAL ||
+			 partition.sector_start == device .sectors
+		   ) {
+			//Must account the relative offset between:
+			// (A) the Extended Boot Record sector and the next track of the
+			//     logical partition (usually 63 sectors), and
+			// (B) the Master Boot Record sector and the next track of the first
+			//     primary partition
+			diff = (partition .sector_start - device .sectors) % device .cylsize ;
+		} else if ( partition.sector_start == 34 ) {
+			// (C) the GUID Partition Table (GPT) and the start of the data
+			//     partition at sector 34
+			diff = (partition .sector_start - 34 ) % device .cylsize ;
+		} else {
+			diff = partition .sector_start % device .cylsize ;
+		}
 		if ( diff )
 		{
 			if ( diff < ( device .cylsize / 2 ) )
@@ -368,6 +359,9 @@ bool GParted_Core::apply_operation_to_disk( Operation * operation )
 					       static_cast<OperationCopy*>( operation ) ->partition_copied .get_length(),
 					       operation ->operation_detail ) ;
 				break ;
+			case OPERATION_LABEL_PARTITION:
+				succes = label_partition( operation ->partition_new, operation ->operation_detail ) ;
+				break ;
 		}
 
 	if ( libparted_messages .size() > 0 )
@@ -527,10 +521,10 @@ void GParted_Core::init_maps()
 	std::ifstream proc_partitions( "/proc/partitions" ) ;
 	if ( proc_partitions )
 	{
-		char c_str[255] ;
+		char c_str[4096+1] ;
 		
 		while ( getline( proc_partitions, line ) )
-			if ( sscanf( line .c_str(), "%*d %*d %*d %255s", c_str ) == 1 )
+			if ( sscanf( line .c_str(), "%*d %*d %*d %4096s", c_str ) == 1 )
 			{
 				line = "/dev/" ; 
 				line += c_str ;
@@ -555,7 +549,7 @@ void GParted_Core::read_mountpoints_from_file( const Glib::ustring & filename,
 					       std::map< Glib::ustring, std::vector<Glib::ustring> > & map ) 
 {
 	std::string line ;
-	char node[255], mountpoint[255] ;
+	char node[4096+1], mountpoint[4096+1] ;
 	unsigned int index ;
 	
 	std::ifstream file( filename .c_str() ) ;
@@ -563,7 +557,7 @@ void GParted_Core::read_mountpoints_from_file( const Glib::ustring & filename,
 	{
 		while ( getline( file, line ) )
 			if ( Glib::str_has_prefix( line, "/" ) &&
-			     sscanf( line .c_str(), "%255s %255s", node, mountpoint ) == 2 &&
+			     sscanf( line .c_str(), "%4096s %4096s", node, mountpoint ) == 2 &&
 			     Glib::ustring( node ) != "/dev/root" )
 			{
 				line = mountpoint ;
@@ -1111,7 +1105,43 @@ bool GParted_Core::Delete( const Partition & partition, OperationDetail & operat
 	operationdetail .get_last_child() .set_status( succes ? STATUS_SUCCES : STATUS_ERROR ) ;
 	return succes ;
 }
-	
+
+bool GParted_Core::label_partition( const Partition & partition, OperationDetail & operationdetail )	
+{
+	if( partition .label .empty() ) {
+		operationdetail .add_child( OperationDetail( String::ucompose(
+														_("Clear partition label on %1"),
+														partition .get_path()
+													 ) ) ) ;
+	} else {
+		operationdetail .add_child( OperationDetail( String::ucompose(
+														_("Set partition label to \"%1\" on %2"),
+														partition .label, partition .get_path()
+													 ) ) ) ;
+	}
+
+	bool succes = false ;
+	if ( partition .type != TYPE_EXTENDED )
+	{
+		switch( get_fs( partition .filesystem ) .set_label )
+		{
+			case FS::EXTERNAL:
+				succes = set_proper_filesystem( partition .filesystem ) &&
+					 p_filesystem ->set_label( partition, operationdetail .get_last_child() ) ;
+				break ;
+			case FS::LIBPARTED:
+				break ;
+
+			default:
+				break ;
+		}
+	}
+
+	operationdetail .get_last_child() .set_status( succes ? STATUS_SUCCES : STATUS_ERROR ) ;
+
+	return succes ;	
+}
+
 bool GParted_Core::resize_move( const Device & device,
 				const Partition & partition_old,
 			  	Partition & partition_new,
@@ -1214,7 +1244,7 @@ bool GParted_Core::move_filesystem( const Partition & partition_old,
 	{
 		operationdetail .add_child( OperationDetail( _("move filesystem") ) ) ;
 		operationdetail .get_last_child() .add_child( 
-			OperationDetail( _("new and old filesystem have the same positition. skipping this operation"),
+			OperationDetail( _("new and old filesystem have the same positition -- skipping this operation"),
 					 STATUS_NONE,
 					 FONT_ITALIC ) ) ;
 
@@ -1419,7 +1449,7 @@ bool GParted_Core::resize_move_partition( const Partition & partition_old,
 	if ( action == NONE )
 	{
 		operationdetail .get_last_child() .add_child( 
-			OperationDetail( _("new and old partition have the same size and position. skipping this operation"),
+			OperationDetail( _("new and old partition have the same size and position -- skipping this operation"),
 					  STATUS_NONE,
 					  FONT_ITALIC ) ) ;
 
@@ -1522,7 +1552,7 @@ bool GParted_Core::resize_filesystem( const Partition & partition_old,
 			operationdetail .add_child( OperationDetail( _("resize filesystem") ) ) ;
 			operationdetail .get_last_child() .add_child( 
 				OperationDetail( 
-					_("new and old filesystem have the same size. skipping this operation"),
+					_("new and old filesystem have the same size -- skipping this operation"),
 					STATUS_NONE,
 					FONT_ITALIC ) ) ;
 		
@@ -2331,9 +2361,6 @@ GParted_Core::~GParted_Core()
 {
 	if ( p_filesystem )
 		delete p_filesystem ;
-
-	//remove .fdi file..
-	remove( "/usr/share/hal/fdi/policy/gparted-disable-automount.fdi" ) ;
 }
 	
 } //GParted
