@@ -35,10 +35,11 @@ Partition::Partition( const Glib::ustring & path )
 void Partition::Reset()
 {
 	paths .clear() ;
-	error .clear() ;
+	messages .clear() ;
 	status = GParted::STAT_REAL ;
 	type = GParted::TYPE_UNALLOCATED ;
 	filesystem = GParted::FS_UNALLOCATED ;
+	label .clear() ;
 	partition_number = sector_start = sector_end = sectors_used = sectors_unused = -1;
 	color .set( "black" ) ;
 	inside_extended = busy = strict = false ;
@@ -148,7 +149,10 @@ void Partition::add_paths( const std::vector<Glib::ustring> & paths, bool clear_
 
 Sector Partition::get_length() const 
 {
-	return sector_end - sector_start + 1 ;
+	if ( sector_start >= 0 && sector_end >= 0 )
+		return sector_end - sector_start + 1 ;
+	else
+		return -1 ;
 }
 
 Glib::ustring Partition::get_path() const
@@ -166,9 +170,10 @@ std::vector<Glib::ustring> Partition::get_paths() const
 
 bool Partition::operator==( const Partition & partition ) const
 {
-	return this ->partition_number == partition .partition_number && 
-	       this ->sector_start == partition .sector_start && 
-	       this ->type == partition .type ;
+	return device_path == partition .device_path &&
+	       partition_number == partition .partition_number && 
+	       sector_start == partition .sector_start && 
+	       type == partition .type ;
 }
 
 bool Partition::operator!=( const Partition & partition ) const
@@ -207,6 +212,20 @@ std::vector<Glib::ustring> Partition::get_mountpoints() const
 	return mountpoints ;
 }
 
+Sector Partition::get_sector() const 
+{
+	return (sector_start + sector_end) / 2 ; 
+}
+	
+bool Partition::test_overlap( const Partition & partition ) const
+{
+	return ( (partition .sector_start >= sector_start && partition .sector_start <= sector_end) 
+		 ||
+		 (partition .sector_end >= sector_start && partition .sector_end <= sector_end)
+		 ||
+		 (partition .sector_start < sector_start && partition .sector_end > sector_end) ) ;
+}
+
 void Partition::clear_mountpoints()
 {
 	mountpoints .clear() ;
